package de.hdm_stuttgart.mi.sda1.catalog2sql;

import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.List;

/**
 * Formatting product related INSERT statements
 *
 */
public class DataInsert {
	
	final Statement stmt;

	/**
	 * @param conn Destination RDBMS
	 * @throws SQLException 
	 */
	public DataInsert(final Connection conn) throws SQLException {
		stmt = conn.createStatement();
	}
	
	/**
	 * Create an SQL INSERT statement corresponding to a &lt;product id='...' &gt; entry
	 * lacking age specification.
	 * @param productId  See {@link #insertproduct(String, String, int)}
	 * @param productName See {@link #insertproduct(String, String, int)}
	 * @throws SQLException 
	 */
	public void insertproduct(final String productId, final String productName) {
      final String sqlInsertStmt = "INSERT INTO Product (id, name) VALUES ('" + productId + "', '" + productName +  "');";
      try {
         stmt.executeUpdate(sqlInsertStmt);
      } catch (SQLException e) {
         Helper.exitWithErrorMessage("Unable to insert product without age property", 1);

      }
	}
	
	/**
	 * Insert dataset corresponding to a &lt;product id='...' &gt; entry
	 * @param productId The product's unique id property
	 * @param productName The product's end user readable name.
	 * @param age The product's age
	 * @throws SQLException 
	 */
	public void insertproduct(final String productId, final String productName, final int age)  {
	   
	   // A PreparedStatement is preferable but not yet introduced in lecture
	   //
		final String sqlInsertStmt = "INSERT INTO Product VALUES ('" + productId + "', '" + productName +  "', " + age + ");";
      try {
         stmt.executeUpdate(sqlInsertStmt);
      } catch (SQLException e) {
         Helper.exitWithErrorMessage("Unable to insert product including age property", 1);
      }
	}

	
	/**
	 * Adding a description to a given product.
	 * 
	 * @param productId The description belongs to this product 
	 * @param descriptions All descriptions belonging to productId
	 * @throws SQLException 
	 */
	public void insertDescription(final String productId, final List<String> descriptions) {
	   
		for (int i = 0; i < descriptions.size(); i++) {
		   final String sqlInsertStmt = "INSERT INTO Description VALUES('" + productId + "', " + i + ", '" +
		                                 descriptions.get(i) + "');";
		   try {
            stmt.executeUpdate(sqlInsertStmt);
         } catch (SQLException e) {
           Helper.exitWithErrorMessage("Unable to insert product description", 1);
         }
		}
	}
	public void close() throws SQLException {
	   stmt.close();
	}
	
}
